@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "cache.h"
 #include "cachefile.h"
 #include "chunk.h"
@@ -82,7 +68,7 @@ bool Cache::mappedModeAllowed()
 Job *Cache::moveDataFiles(const QMap<TorrentFileInterface *, QString> &files)
 {
     Q_UNUSED(files);
-    return 0;
+    return nullptr;
 }
 
 void Cache::moveDataFilesFinished(const QMap<TorrentFileInterface *, QString> &files, Job *job)
@@ -162,7 +148,7 @@ void Cache::saveMountPoints(const QSet<QString> &mp)
         throw Error(i18n("Failed to create %1: %2", mp_file, fptr.errorString()));
 
     QTextStream out(&fptr);
-    for (const QString &mount_point : qAsConst(mount_points)) {
+    for (const QString &mount_point : std::as_const(mount_points)) {
         out << mount_point << Qt::endl;
     }
 }
@@ -193,7 +179,7 @@ bool Cache::isStorageMounted(QStringList &missing)
         return true;
 
     missing.clear();
-    for (const QString &mount_point : qAsConst(mount_points)) {
+    for (const QString &mount_point : std::as_const(mount_points)) {
         if (!IsMounted(mount_point))
             missing.append(mount_point);
     }
