@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "multifilecache.h"
 #include <QSet>
 #include <QTextStream>
@@ -242,7 +228,7 @@ Job *MultiFileCache::moveDataFiles(const QString &ndir)
 
     if (nmoves == 0) {
         delete job;
-        return 0;
+        return nullptr;
     } else {
         return job;
     }
@@ -267,7 +253,7 @@ void MultiFileCache::moveDataFilesFinished(Job *job)
 Job *MultiFileCache::moveDataFiles(const QMap<TorrentFileInterface *, QString> &files)
 {
     if (files.count() == 0)
-        return 0;
+        return nullptr;
 
     MoveDataFilesJob *job = new MoveDataFilesJob(files);
     return job;
@@ -374,7 +360,7 @@ PieceData::Ptr MultiFileCache::createPiece(Chunk *c, Uint32 off, Uint32 length,
 
         if (Cache::mappedModeAllowed() && mmap_failures < 3) {
             Uint64 offset = FileOffset(c, f, tor.getChunkSize()) + off;
-            PieceData::Ptr piece(new PieceData(c, off, length, 0, fd, read_only));
+            PieceData::Ptr piece(new PieceData(c, off, length, nullptr, fd, read_only));
             Uint8 *buf = (Uint8 *)fd->map(piece.data(), offset, length, read_only ? CacheFile::READ : CacheFile::RW);
             if (buf) {
                 piece->setData(buf);
